<?php
/**
 * RenderCheckout Init
 *
 * @version 1.0.1
 * @package 'datalayer'
 */

namespace DatalayerForWoocommerceFree;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'RenderCheckout' ) ) :

	/**
	 * Class RenderCheckout
	 */
	class RenderCheckout {

		/**
		 * Measuring Checkout Step Transaction
		 *
		 * @param int $transaction_id     Get global Transaction.
		 * @name 'measuring_checkout_purchase_data_layer'
		 */
		public static function measuring_checkout_purchase_data_layer( $transaction_id ) {
			$order = wc_get_order( $transaction_id );
			/** $user                 = $order->get_user(); */
			/** $products             = $order->get_items(); */
			$transaction_total    = $order->get_total();
			$transaction_tax      = $order->get_total_tax();
			$transaction_shipping = $order->get_shipping_total();

			$email      = $order->get_billing_email();
			$first_name = $order->get_billing_first_name();
			$last_name  = $order->get_billing_last_name();

			$status = $order->get_status();

			$coupons = $order->get_coupon_codes();
			$coupon  = '';
			if ( is_array( $coupons ) ) {
				foreach ( $coupons as $item ) {
					$coupon = $item;
				}
			}

			if ( DataLayer::is_data_layer_ua() ) {
				$product_data = array();
				foreach ( $order->get_items() as $item ) {
					$sku   = $item->get_product_id();
					$price = $order->get_item_total( $item );

					$product_categories = get_the_terms( $sku, 'product_cat' );
					if ( ( is_array( $product_categories ) ) && ( count( $product_categories ) > 0 ) ) {
						$product_cat = array_pop( $product_categories );
						$product_cat = $product_cat->name;
					} else {
						$product_cat = '';
					}

					$product_data[] = array( // List of productFieldObjects.
						'name'     => $item['name'], // Name or ID is required.
						'id'       => $sku,
						'price'    => $price,
						/** 'brand'=> */
						'category' => $product_cat,
						/** 'variant'=> */
						'quantity' => $item['qty'],
					);
				}

				$data_layer = array(
					'event_id'         => DataLayer::generate_event_id_datalayer(),
					'ecommerce'          => array(
						'currencyCode' => get_option( 'woocommerce_currency' ),
						'purchase'     => array(
							'actionField' => array(
								'id'          => $transaction_id, // Required // Transaction ID. Required for purchases and refunds.
								'affiliation' => 'Online Store',
								'revenue'     => $transaction_total,
								'tax'         => $transaction_tax,
								'shipping'    => $transaction_shipping,
								'coupon'      => $coupon,
							),
							'products'    => $product_data,
							'status'      => $status,
						),
					),
					'visitorContactInfo' => array(
						'name'  => $first_name . ' ' . $last_name,
						'email' => $email,
					),
				);
			}

			if ( DataLayer::is_data_layer_ga4() ) {
				$product_data = array();
				foreach ( $order->get_items() as $item ) {
					$sku   = $item->get_product_id();
					$price = $order->get_item_total( $item );

					$product_categories = get_the_terms( $sku, 'product_cat' );
					if ( ( is_array( $product_categories ) ) && ( count( $product_categories ) > 0 ) ) {
						$product_cat = array_pop( $product_categories );
						$product_cat = $product_cat->name;
					} else {
						$product_cat = '';
					}

					$product_data[] = array( // List of productFieldObjects.
						'item_name'     => $item['name'], // Name or ID is required.
						'item_id'       => $sku,
						'price'         => (float) $price,
						/** 'item_brand' => */
						'item_category' => $product_cat,
						/** 'item_variant'  => , */
						'quantity'      => (float) $item['qty'],
					);
				}

				$currency_code = get_option( 'woocommerce_currency' );

				$data_layer = array(
					'event'              => 'purchase',
					'event_id'           => DataLayer::generate_event_id_datalayer(),
					'ecommerce'          => array(
						'currency'       => $currency_code,
						'transaction_id' => $transaction_id, // Required // Transaction ID. Required for purchases and refunds.
						'affiliation'    => 'Online Store',
						'value'          => (float) $transaction_total,
						'tax'            => (float) $transaction_tax,
						'shipping'       => (float) $transaction_shipping,
						'coupon'         => $coupon,
						'items'          => $product_data,
						'status'         => $status,
					),
					'visitorContactInfo' => array(
						'name'  => $first_name . ' ' . $last_name,
						'email' => $email,
					),
				);
			}

			DataLayer::push_to_data_layer( $data_layer );

		}

	}
endif;
