<?php
/**
 * RenderProduct Init
 *
 * @version 1.0.1
 * @package 'datalayer'
 */

namespace DatalayerForWoocommerceFree;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'RenderProduct' ) ) :
	/**
	 * Class RenderProduct
	 */
	class RenderProduct {

		/**
		 * Measuring product detail e product related
		 *
		 * @param object $product    Product.
		 * @param array  $products_related   Product Related.
		 * @name 'mount_measuring_views_of_product_details_data_layer'
		 */
		public static function mount_measuring_views_of_product_details_data_layer( $product, $products_related ) {

			if ( DataLayer::is_data_layer_ua() ) {
				$category_ids = $product->get_category_ids();
				$category     = '';
				if ( isset( $category_ids[0] ) ) {
					$category = get_the_category_by_ID( $category_ids[0] );
				}

				$impressions = array();
				$count       = 1;
				foreach ( $products_related as $product_related ) :
					$category_ids = $product_related->get_category_ids();
					$category     = '';
					if ( isset( $category_ids[0] ) ) {
						$category = get_the_category_by_ID( $category_ids[0] );
					}
					$impressions[] = array(
						'name'     => $product_related->get_name(),
						'id'       => $product_related->get_id(),
						'sku'      => $product_related->get_sku(),
						'price'    => $product_related->get_price(),
						/** 'brand'=>$product->, */
						'category' => $category,
						/** 'variant'=>$variant, */
						'list'     => 'Related Products',
						'position' => $count,
					);
					$count++;
				endforeach;

				$currency_code = get_option( 'woocommerce_currency' );

				$data_layer = array(
					'event_id'  => DataLayer::generate_event_id_datalayer(),
					'ecommerce' => array(
						'currencyCode' => $currency_code,
						'impressions'  => $impressions,
						'detail'       => array(
							'products' => array(
								'name'     => $product->get_name(), // Name or ID is required.
								'id'       => $product->get_id(),
								'sku'      => $product->get_sku(),
								'price'    => $product->get_price(),
								/** 'brand'=>$product->, */
								'category' => $category,
								/** 'variant'=>$variant, */
							),
						),
					),
				);
			}

			if ( DataLayer::is_data_layer_ga4() ) {
				$category_ids = $product->get_category_ids();
				$category     = '';
				if ( isset( $category_ids[0] ) ) {
					$category = get_the_category_by_ID( $category_ids[0] );
				}

				$currency_code = get_option( 'woocommerce_currency' );

				$data_layer = array(
					'event'     => 'view_item',
					'event_id'  => DataLayer::generate_event_id_datalayer(),
					'ecommerce' => array(
						'currency' => $currency_code,
						'items'    => array(
							array(
								'item_name'     => $product->get_name(), // Name or ID is required.
								'item_id'       => $product->get_id(),
								'price'         => (float) $product->get_price(),
								/** 'item_brand' => */
								'item_category' => $category,
								'quantity'      => 1,
								/** 'item_variant': Gray, */
								/**  'item_list_name' => '', If associated with a list selection.*/
								/** 'item_list_id' => $list,*/
								/** 'index'          =>, */
							),
						),
					),
				);
			}

			DataLayer::push_to_data_layer( $data_layer );

		}

	}
endif;
